@@ -312,7 +312,8 @@ class ft_fix():
         try:
             for acc in self.accounts_run:
                 ft_position_collection =  self.order_info_db[acc]['ft_position']
-                all_position_query = {"trade_acc": self.account_id}
+                account_id = self.account_id[acc]
+                all_position_query = {"trade_acc": account_id}
                 targets = ft_position_collection.find(all_position_query)
             
                 if targets.count() > 0:
@@ -324,9 +325,9 @@ class ft_fix():
                         lock_vol = pos['lock_vol']
                         accountName = self.target_account_names[acc]
                         query = {'ticker': ticker, 'accountName': accountName}
-                        EquityPosition_targets = self.order_info_db[acc]['EquityPosition'].find(query).sort('enterdate')
+                        EquityPosition_targets = self.order_info_db[acc]['EquityPosition'].find(query)
                         if EquityPosition_targets.count() == 0 and not pos['ticker'] == '' and not total_vol == 0:
-                            self.add_position_for_debug(pos, ticker, td_vol, yd_vol, accountName)
+                            self.add_position_for_debug(acc, pos, ticker, td_vol, yd_vol, accountName)
                         elif not pos['ticker'] == '':
                             td_vol_indb = 0
                             yd_vol_indb = 0
